@@ -1,6 +1,8 @@
 ﻿# -*- coding: utf-8 -*-
+
 ###########################################################################
-## All global variables in here are used all over the program
+## File:		data.py
+## Description: This file includes all global variables not related to the records
 ###########################################################################
 
 configFolder="/home/user/.SleepAnalyser/" #users home dir with ending /
@@ -47,7 +49,6 @@ DisplayIsOn=True
 ScrollToEnd=False
 
 
-#init values
 Sampling_interval=1000 #in milliseconds
 Sample_index=0
 Sample_smoothing=10 #value_smoothing at 1. level
@@ -70,8 +71,8 @@ Xscale=1 #default value X scale in arraXscale index
 derivation_offset=2
 
 
-Value_index=0
-Values_total=0
+#Value_index=0
+#Values_total=0
 
 arrRecordFiles=[]
 arrRecordFilesIndex=0
@@ -101,11 +102,9 @@ LastWindow=""
 
 user=""
 app_path="./"
-#passed_time=0
-#passed_time2=0
-#DropIndexes=0
+
 last_beep=0
-#graphBlocks=0
+
 
 SwitchedModes=False
 OfflineMode=False
@@ -121,19 +120,13 @@ UIStyle=""
 
 DelayStart=0
 interval=0
-#GraphStart=0
-#GraphStartHours=0
-#GraphStartMinutes=0
-#AlarmTimeSec=0 #absolute alarm time in seconds
-#AlarmDate=0
+
 AlarmHour=7
 AlarmMinute=0
 UseAlarm=False
 AlarmIsActive=False
 AlarmTimeWindow=30 #in minutes
 AlarmID=-1 #cookie for communication to system
-#EventSetAlarm=-1
-#EventEffectiveAlarm=-1
 
 StopAfterAlarm=True
 
@@ -141,11 +134,7 @@ Status=""
 Progress=""
 
 #arrays, indexes, lenghts
-#arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
-#arrDataLen=8640 #(1 value/10sec for 24h), 6*24*60
-##old             [0]=time            [1]=X,                [2]=Y,                [3]=X Derivation,[4]=Y Derivation
-#             [0]=time            [1]=X,                [2]=Y,                [3]=X+Y Derivation, [4]=Time since last movement over treshhold, [5]=event
-#arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,        [0]*arrDataLen ,             [0]*arrDataLen]
+#             [0]=time            [1]=X, [2]=Y, [3]=X+Y Derivation, [4]=Time since last movement over treshhold, [5]=event
 arrDataTemp=[0, 0, 0] #[0]=X, [1]=Y, [2]=Z
 arrDataIndex=0
 arrRecordFiles=[]
@@ -170,7 +159,7 @@ Lucid_Dream_Color=      "#00C800" #"#B3FF8F"
 WakeUp_Color=             "red" #"#FEA2FF"
 
 
-noiseReduction=4  #Smoothing of derivation data
+#noiseReduction=4  #Smoothing of derivation data
 
 
 limitMovement=250
